pulp_file
=========

.. figure:: https://github.com/pulp/pulp_file/workflows/Pulp%20CI/badge.svg
   :alt: Pulp CI

.. image:: https://coveralls.io/repos/pulp/pulp_file/badge.png?branch=master
   :target: https://coveralls.io/r/pulp/pulp_file?branch=master

A Pulp plugin to support hosting arbitrary files.

For more information, please see the `documentation <https://docs.pulpproject.org/pulp_file/>`_
or the `Pulp project page <https://pulpproject.org>`_.
